@@ -5,10 +5,6 @@ saltfactories.factories.manager
 
 Salt Factories Manager
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import sys
 
@@ -890,6 +886,15 @@ class SaltFactoriesManager(object):
             **extra_daemon_class_kwargs
         )
 
+    def get_salt_client(self, master_id, functions_known_to_return_none=None):
+        """
+        Return a local salt client object
+        """
+        return salt_factories.SaltClient(
+            master_config=self.cache["configs"]["masters"][master_id].copy(),
+            functions_known_to_return_none=functions_known_to_return_none,
+        )
+
     def get_salt_cli(self, master_id, **cli_kwargs):
         """
         Return a `salt` CLI process
