@@ -5,14 +5,11 @@
 
     Base process classes
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import atexit
 import json
 import logging
 import os
+import pprint
 import subprocess
 import sys
 import tempfile
@@ -71,19 +68,19 @@ class Popen(subprocess.Popen):
             self.__stdout.seek(0)
             stdout = self.__stdout.read()
 
-            if six.PY3:
-                # pylint: disable=undefined-variable
-                stdout = stdout.decode(__salt_system_encoding__)
-                # pylint: enable=undefined-variable
+            # We want str type on Py3 and Unicode type on Py2
+            # pylint: disable=undefined-variable
+            stdout = stdout.decode(__salt_system_encoding__)
+            # pylint: enable=undefined-variable
         if self.__stderr:
             self.__stderr.flush()
             self.__stderr.seek(0)
             stderr = self.__stderr.read()
 
-            if six.PY3:
-                # pylint: disable=undefined-variable
-                stderr = stderr.decode(__salt_system_encoding__)
-                # pylint: enable=undefined-variable
+            # We want str type on Py3 and Unicode type on Py2
+            # pylint: disable=undefined-variable
+            stderr = stderr.decode(__salt_system_encoding__)
+            # pylint: enable=undefined-variable
         return stdout, stderr
 
 
@@ -106,6 +103,20 @@ class ProcessResult(namedtuple("ProcessResult", ("exitcode", "stdout", "stderr",
     stderr = property(itemgetter(2), doc="ProcessResult stderr property")
     cmdline = property(itemgetter(3), doc="ProcessResult cmdline property")
 
+    def __str__(self):
+        message = self.__class__.__name__
+        if self.cmdline:
+            message += "\n Command Line: {}".format(self.cmdline)
+        if self.exitcode is not None:
+            message += "\n Exitcode: {}".format(self.exitcode)
+        if self.stdout or self.stderr:
+            message += "\n Process Output:"
+        if self.stdout:
+            message += "\n   >>>>> STDOUT >>>>>\n{}\n   <<<<< STDOUT <<<<<".format(self.stdout)
+        if self.stderr:
+            message += "\n   >>>>> STDERR >>>>>\n{}\n   <<<<< STDERR <<<<<".format(self.stderr)
+        return message + "\n"
+
 
 class ShellResult(namedtuple("ShellResult", ("exitcode", "stdout", "stderr", "json", "cmdline"))):
     """
@@ -129,6 +140,23 @@ class ShellResult(namedtuple("ShellResult", ("exitcode", "stdout", "stderr", "js
     json = property(itemgetter(3), doc="ShellResult stdout JSON decoded, when parseable.")
     cmdline = property(itemgetter(4), doc="ShellResult cmdline property")
 
+    def __str__(self):
+        message = self.__class__.__name__
+        if self.cmdline:
+            message += "\n Command Line: {}".format(self.cmdline)
+        if self.exitcode is not None:
+            message += "\n Exitcode: {}".format(self.exitcode)
+        if self.stdout or self.stderr:
+            message += "\n Process Output:"
+        if self.stdout:
+            message += "\n   >>>>> STDOUT >>>>>\n{}\n   <<<<< STDOUT <<<<<".format(self.stdout)
+        if self.stderr:
+            message += "\n   >>>>> STDERR >>>>>\n{}\n   <<<<< STDERR <<<<<".format(self.stderr)
+        if self.json:
+            message += "\n JSON Object:\n"
+            message += "".join("  {}".format(line) for line in pprint.pformat(self.json))
+        return message + "\n"
+
     def __eq__(self, other):
         """
         Allow comparison against the parsed JSON or the output
@@ -146,6 +174,26 @@ class FactoryProcess(object):
     def __init__(
         self, cli_script_name, slow_stop=True, environ=None, cwd=None, base_script_args=None,
     ):
+        """
+
+        Args:
+            cli_script_name(str):
+                This is the string containing the name of the binary to call on the subprocess, either the
+                full path to it, or the basename. In case of the basename, the directory containing the
+                basename must be in your ``$PATH`` variable.
+            slow_stop(bool):
+                Wether to terminate the processes by sending a :py:attr:`SIGTERM` signal or by calling
+                :py:meth:`~subprocess.Popen.terminate` on the sub-procecess.
+                When code coverage is enabled, one will want `slow_stop` set to `True` so that coverage data
+                can be written down to disk.
+            environ(dict):
+                A dictionary of `key`, `value` pairs to add to the environment.
+            cwd (str):
+                The path to the current working directory
+            base_script_args(list or tuple):
+                An list or tuple iterable of the base arguments to use when building the command line to
+                launch the process
+        """
         self.cli_script_name = cli_script_name
         self.slow_stop = slow_stop
         self.environ = environ or os.environ.copy()
@@ -290,6 +338,15 @@ class FactoryScriptBase(FactoryProcess):
     """
 
     def __init__(self, *args, **kwargs):
+        """
+        Base class for non daemonic CLI processes
+
+        Check base class(es) for additional supported parameters
+
+        Args:
+            default_timeout(int):
+                The maximum ammount of seconds that a script should run
+        """
         default_timeout = kwargs.pop("default_timeout", None)
         super(FactoryScriptBase, self).__init__(*args, **kwargs)
         if default_timeout is None:
@@ -371,6 +428,15 @@ class FactoryScriptBase(FactoryProcess):
 
 class FactoryPythonScriptBase(FactoryScriptBase):
     def __init__(self, *args, **kwargs):
+        """
+        Base class for python scripts based CLI processes
+
+        Check base class(es) for additional supported parameters
+
+        Args:
+            python_executable(str):
+                The path to the python executable to use
+        """
         python_executable = kwargs.pop("python_executable", None)
         super(FactoryPythonScriptBase, self).__init__(*args, **kwargs)
         self.python_executable = python_executable or sys.executable
