@@ -5,10 +5,6 @@
 
     Exceptions unit tests
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import textwrap
 import traceback
 
